@@ -116,7 +116,6 @@ NR0 <- function(start,objective,gradient,hessian,debug=FALSE,control,...) {
     }
     oneiter <- function(p.orig) {
         if (is.null(hessian)) {
-            cat(".")
             I <- numDeriv::jacobian(gradient,p.orig,method=lava.options()$Dmethod)
         } else {
             I <- hessian(p.orig)
@@ -177,8 +176,9 @@ NR0 <- function(start,objective,gradient,hessian,debug=FALSE,control,...) {
 
 ###{{{ NR 2
 
+##' @export
 NR <- function(start,objective,gradient,hessian,debug=FALSE,control,...) {
-    control0 <- list(trace=0,gamma=1,lambda=0,ngamma=0,gamma2=0,backtrace=FALSE,
+    control0 <- list(trace=0,gamma=1,lambda=0,ngamma=0,gamma2=0,backtrace=TRUE,
                      iter.max=200,tol=1e-9,stabil=FALSE,epsilon=1e-9)
     if (!missing(control)) {
         control0[names(control)] <- control
@@ -249,6 +249,7 @@ NR <- function(start,objective,gradient,hessian,debug=FALSE,control,...) {
             }
         }
         p <- p.orig + Lambda*Delta
+        Lambda <- Lambda^.5
         return(list(p=p,D=D,iI=iI))
     }
     
@@ -282,5 +283,4 @@ NR <- function(start,objective,gradient,hessian,debug=FALSE,control,...) {
     return(res)
 }
 
-
 ###}}} Newton Raphson/Scoring
