@@ -1,6 +1,6 @@
 ###{{{ print.lvm
 
-##' @S3method print lvm
+##' @export
 `print.lvm` <-
 function(x, ...) {
   res <- NULL
@@ -52,27 +52,24 @@ function(x, ...) {
 
 ###{{{ print.lvmfit
 
-##' @S3method print lvmfit
+##' @export
 `print.lvmfit` <-
 function(x,level=2,labels=FALSE,...) {
-##    print(signif(coef(x), digits=digits), print.gap=2, quote=FALSE, ...)
-##  if (index(x)$npar.reg==0 & level==0) level <- 1
-##  coefs <- coef(x, level=level, ...);
-##  coefs[coefs[,4]==0,4] <- 1e-16
-##  printCoefmat(coefs, na.print="NA", signif.stars=signif.stars,...)
-##  cat("---\n")
-#  cat("\n", rep("-", 50), "\n\n", sep="");
-  print(CoefMat(x,labels=labels,level=level,...),quote=FALSE,right=TRUE)
-#  cat("\n", rep("-", 50), "\n\n", sep="");
-  invisible(x)
-##  invisible(coefs)
+    print(CoefMat(x,labels=labels,level=level,...),quote=FALSE,right=TRUE)
+    minSV <- attr(vcov(x),"minSV")
+    if (!is.null(minSV) && minSV<1e-12) {
+        warning("Small singular value: ", format(minSV))
+    }
+    pseudo <- attr(vcov(x),"pseudo")
+    if (!is.null(pseudo) && pseudo) warning("Singular covariance matrix. Pseudo-inverse used.")
+    invisible(x)
 }
 
 ###}}} print.lvmfit
 
 ###{{{ print.lvmfit.randomslope
 
-##' @S3method print lvmfit.randomslope
+##' @export
 print.lvmfit.randomslope <- function(x,labels=FALSE,level=2,...) {
   print(CoefMat(x,labels=labels,level=level,...),quote=FALSE,right=TRUE)
   invisible(x)
@@ -82,7 +79,7 @@ print.lvmfit.randomslope <- function(x,labels=FALSE,level=2,...) {
 
 ###{{{ print.multigroupfit
 
-##' @S3method print multigroupfit
+##' @export
 print.multigroupfit <- function(x,groups=NULL,...)  {
   if (is.null(groups)) {
     if (x$model$missing) {
@@ -132,7 +129,7 @@ print.multigroupfit <- function(x,groups=NULL,...)  {
 
 ###{{{ print.multigroup
 
-##' @S3method print multigroup
+##' @export
 print.multigroup <- function(x,...) {
   cat("\n")
   cat("Number of groups:", x$ngroup, "\n")
