@@ -2,7 +2,7 @@
 ##' data types he operator is a wrapper of \code{paste}.
 ##'
 ##' Concatenation operator
-##' @aliases %+%
+##' @aliases %+% %++%
 ##' @rdname op_concat
 ##' @usage x \%+\% y
 ##' @title Concatenation operator
@@ -17,10 +17,19 @@
 ##' @export
 `%+%` <- function(x,y) UseMethod("%+%",y)
 
-##' @S3method %+% default
+##' @export
+`%++%` <- function(x,y) UseMethod("%+%",y)
+
+##' @export
+`%++%.default` <- function(x,y) x%+%y
+
+##' @export
 `%+%.default` <- function(x,y) paste(x,y,sep="")
 
-##' @S3method %+% matrix
+##' @export
+`%+%.character` <- function(x,y) paste(x,y,sep="")
+
+##' @export
 `%+%.matrix` <- function(x,y) blockdiag(x,y)
 
 
